@@ -1,8 +1,12 @@
-from servicecatalog_puppet.waluigi.threads import topological_generations as threads_topological_generations
-from servicecatalog_puppet.waluigi.processes import topological_generations as processes_topological_generations
+from servicecatalog_puppet.waluigi.threads import (
+    topological_generations as threads_topological_generations,
+)
+from servicecatalog_puppet.waluigi.processes import (
+    topological_generations as processes_topological_generations,
+)
 
 
-def get_scheduler(threads_or_processes, algorithm):
+def get_scheduler(threads_or_processes: str, algorithm: str):
     name = f"{threads_or_processes}.{algorithm}"
     print(f"Using scheduler: {name}")
     if name == "threads.topological_generations":
@@ -10,4 +14,4 @@ def get_scheduler(threads_or_processes, algorithm):
     if name == "processes.topological_generations":
         return processes_topological_generations
 
-    raise Exception(f"Unsupported scheduler: {name}")
\ No newline at end of file
+    raise Exception(f"Unsupported scheduler: {name}")
